@@ -23,9 +23,6 @@
 
 package Utils::Backend;
 
-use Net::DBus;
-use Net::DBus::Service;
-use Net::DBus::Reactor;
 use Utils::Report;
 use Utils::Platform;
 
@@ -43,7 +40,7 @@ sub print_usage
 
   my $usage_text =<< "end_of_usage_text;";
         NOTE: You should not be running this directly, this is only
-              recomended for debuggin purposes.
+              recomended for debugging purposes.
 
        Usage: SystemToolsBackends.pl options
 
@@ -64,6 +61,8 @@ sub print_usage
 
   --disable-shutdown  Disable default shutdown timeout of 180 seconds.
 
+    --list-platforms  List available platforms.
+
 end_of_usage_text;
 
   print STDERR $usage_text;
@@ -71,6 +70,21 @@ end_of_usage_text;
   exit $exit_code if $exit_code ne undef;
 }
 
+sub print_platform_list
+{
+  my ($platforms) = &Utils::Platform::get_platform_info ();
+
+  foreach $platform (keys %$platforms)
+  {
+    my $value = $$platforms{$platform};
+    my $desc = join (" ", @$value);
+
+    printf ("%s\t- %s\n", $platform, $desc);
+  }
+
+  exit 0;
+}
+
 # --- Initialization and finalization --- #
 
 sub set_with_param
@@ -118,19 +132,6 @@ sub set_dist
   &set_with_param ($tool, "platform", $dist);
 }
 
-sub ensure_platform
-{
-  if (!$tool{"platform"})
-  {
-    my $bus = Net::DBus->system;
-    my $service = $bus->get_service("org.freedesktop.SystemToolsBackends");
-    my $obj = $service->get_object ("/org/freedesktop/SystemToolsBackends/Platform");
-    my $platform = $obj->getPlatform ();
-
-    &set_dist (\%tool, $platform) if ($platform);
-  }
-}
-
 sub init
 {
   my (@args) = @_;
@@ -148,6 +149,7 @@ sub init
     elsif ($arg eq "--platform")                  { &set_dist      (\%tool, shift @args); }
     elsif ($arg eq "--disable-shutdown")          { &set_disable_shutdown (\%tool); }
     elsif ($arg eq "--verbose"   || $arg eq "-v") { &set_with_param (\%$tool, "do_verbose", 1); }
+    elsif ($arg eq "--list-platforms")            { &print_platform_list (\%tool) }
     else
     {
       print STDERR "Error: Unrecognized option '$arg'.\n\n";
@@ -155,48 +157,11 @@ sub init
     }
   }
 
-  if (!$tool{"module"})
-  {
-    print STDERR "Error: You must specify a module to load.\n\n";
-    &print_usage ($tool, 1);
-  }
-
   # Set up subsystems.
   &Utils::Report::begin ();
   &Utils::Platform::get_system ();
-  &initialize_timer (\%tool);
 
   return \%tool;
 }
 
-sub get_bus
-{
-  return Net::DBus->session
-}
-
-sub run
-{
-  Net::DBus::Reactor->main->run ();
-}
-
-sub shutdown
-{
-  # exit the main loop
-  Net::DBus::Reactor->main->shutdown ();
-}
-
-sub initialize_timer
-{
-  my ($tool) = @_;
-
-  if (!$$tool{"no-shutdown"})
-  {
-    # remove previous timer
-    Net::DBus::Reactor->main->remove_timeout ($$tool{"timer"}) if ($$tool {"timer"});
-
-    #wait three minutes until shutdown
-    $$tool{"timer"} = Net::DBus::Reactor->main->add_timeout (180000, Net::DBus::Callback->new(method => \&shutdown));
-  }
-}
-
 1;
